.spinner-size{height:30px;width:30px;margin:200px}.flex-container{display:flex;align-items:center;justify-content:center;align-content:center;flex-wrap:wrap;flex-direction:row}
/*# sourceMappingURL=main.9671a1b4.chunk.css.map */