# Generated by Django 3.2.5 on 2021-08-27 11:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0058_auto_20210808_0635'),
        ('moons', '0009_alter_miningtax_flat_tax_rate'),
    ]

    operations = [
        migrations.AddField(
            model_name='miningobservation',
            name='moon',
            field=models.ForeignKey(blank=True, default=None, null=True,
                                    on_delete=django.db.models.deletion.SET_NULL, to='corptools.mapsystemmoon'),
        ),
    ]
